require 'git-blame-color/ext/string'


module Git
  module BlameColor
    class Commit
      attr_reader :hash, :line_number, :author, :email, :timestamp, :timezone, :summary, :edited_line

      def initialize(block)
        @hash = block[0].split(' ')[0]
        @line_number = block[0].split(' ')[2].to_i
        @author = find_key(block, 'author').value
        @email = find_key(block, 'author-mail').value.gsub(/[<>]/, '')
        @timestamp = find_key(block, 'author-time').value.to_i
        @timezone = find_key(block, 'author-tz').value
        @summary = find_key(block, 'summary').value
        @edited_line = block.last.gsub(/^\t/, '')
        @is_boundary = !find_key(block, 'boundary').nil?
      end

      def boundary?
        @is_boundary
      end

      private

      def find_key(block, key)
        block.find { |line| line.key == key }
      end
    end
  end
end
